#
# spec file for package perl-Config-Tiny
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Config-Tiny
Name:           perl-Config-Tiny
Version:        2.300.0
Release:        2.4
%define cpan_version 2.30
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Read/Write .ini style files with as little code as possible
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RS/RSAVAGE/%{cpan_name}-%{cpan_version}.tgz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Spec) >= 3.30
BuildRequires:  perl(File::Temp) >= 0.22
BuildRequires:  perl(Test::More) >= 1.001002
Requires:       perl(File::Spec) >= 3.30
Requires:       perl(File::Temp) >= 0.22
Provides:       perl(Config::Tiny) = 2.300.0
%undefine       __perllib_provides
%{perl_requires}

%description
'Config::Tiny' is a Perl class to read and write .ini style configuration
files with as little code as possible, reducing load time and memory
overhead.

Most of the time it is accepted that Perl applications use a lot of memory
and modules.

The '*::Tiny' family of modules is specifically intended to provide an
ultralight alternative to the standard modules.

This module is primarily for reading human written files, and anything we
write shouldn't need to have documentation/comments. If you need something
with more power move up to Config::Simple, Config::General or one of the
many other 'Config::*' modules.

Lastly, Config::Tiny does *not* preserve your comments, whitespace, or the
order of your config file.

See Config::Tiny::Ordered (and possibly others) for the preservation of the
order of the entries in the file.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Oct 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.30
  see /usr/share/doc/packages/perl-Config-Tiny/Changelog.ini
  [V 2.30]
  Date=2023-10-12T17:17:08
  Comments= <<EOT
  - As of V 2.30, this module supports an array syntax for cases where you wish to
  assign an array of values to a key.
  - See the new POD section called ARRAY SYNTAX.
  - See also the updated question in the FAQ: What happens if a key is repeated?
  - See also the sample code in the Synopsis and in t/02.main.t and in t/test.conf.
  - In each case, search for the word greetings to find the new code samples.
  - This patch was kindly provided by Steven Schoch, with some additions by Ron Savage.
  EOT
* Mon Apr 24 2023 Andrew Daugherity <adaugherity@tamu.edu>
- fix build on SLES 12 (no make_build macro)
* Thu Apr  6 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.29
  see /usr/share/doc/packages/perl-Config-Tiny/Changelog.ini
  [V 2.29]
  Date=2023-04-05T12:53:00
  Comments= <<EOT
  - Edit to remove Test::Pod from TEST_REQUIRES in Makefile.PL, again.
  Thanx to Andrew Daugherity for the patch.
  - Update versiojnn # in t/02.main.t.
  EOT
* Wed Jan  5 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.28
  see /usr/share/doc/packages/perl-Config-Tiny/Changelog.ini
  [V 2.28]
  Date=2022-01-04T15:47:58
  Comments= <<EOT
  - Accept pull request from Todd Rinaldo to replace both uses of bareword filehandles
  with my variables. With thanx.
  - Accept 2019 pull request to Makefile.PL, for the purpose of modernization, and with
  some slight modifications, from Grinnz.
  - Make corresponding patches where appropriate to Tiny.pm and t/02.main.t.
  - Thanx to Grinnz aka Dan Book for the prompting.
  EOT
* Thu Sep 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.27
  see /usr/share/doc/packages/perl-Config-Tiny/Changelog.ini
  [V 2.27]
  Date=2021-09-21T15:48:00
  Comments= <<EOT
  - Add the option of passing a hashref to the constructor, where it is turned into an
  object of the class. See POD under new([$config]) for details.
  This patch to the code and POD includes the new test t/08.constructor.t.
  The patch was provided by D Hauke, with thanx.
  - Move test.conf back into t/, where it was years ago, before someone tried to remove
  all uses of File::Spec. But since File::Spec is used often now, there is no point
  in keeping test.conf in the root directory of the distro.
  EOT
* Tue Feb  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.26
  see /usr/share/doc/packages/perl-Config-Tiny/Changelog.ini
* Thu Aug  1 2019 Stephan Kulow <coolo@suse.com>
- Update to 0.24
  - Delete from caveats in documentation where it used to say:
    'Config::Tiny will only recognize the first time an option is set in a config file.'
    'Any further attempts to set the same option later in the config file are ignored.'
    In reality the code uses the 2nd and subsequent values to overwrite earlier values.
  - Make this topic a new FAQ.
  - Add corresponding test t/06.repeat.key.t.
  - Update POD to clarify trailing comment options.
  - Add corresponding test t/07.trailing.comment.t.
  - Romanize Gregory Kidrenko's name so Config::IniFiles does not get 'Wide char in print'.
  - Move xt/pod.t to xt/author/pod.t.
  - Adopt new repo structure. See
    http://savage.net.au/Ron/html/My.Workflow.for.Building.Distros.html.
  - Move require 5.008001 from Tiny.pm into Makefile.PL.
* Sun Oct  8 2017 coolo@suse.com
- updated to 2.23
  see /usr/share/doc/packages/perl-Config-Tiny/Changelog.ini
  [V 2.23]
  Date=2015-10-14T09:11:00
  Comments= <<EOT
  - Add the utf8 BOM to this file. Let's hope the CPAN toolchain can cope. If it can't, another
  version of the code will have to be released.
  - Fix read() and write() so they work on files called '0' (zero). See RT#107754.
  Many thanx to Григорий Кудренко for the report and patch.
  - Add t/05.zero.t and t/0 to test the new code.
  - Reformat the source slightly.
  EOT
* Sat Mar 21 2015 mpluskal@suse.com
- Update to 2.22
  * Fix licence info in Makefile.PL to say Perl.
- Changes for 2.21
  * Patch Makefile.PL to refer to the current repo, which is on
    github, and not the original one, which is on Adam's web site.
    See RT#102125.
  * Remove Build.PL because Karen Etheridge tells me Module::Build
    is no longer in core. See RT#102126.
  * Edit line lengths in this file to a max of 100 chars.
  * Edit line lengths in the docs the same way.
  * Expand the See Also section of the docs.
* Tue Nov 26 2013 coolo@suse.com
- updated to 2.20
  - Relax pre-req version requirements
* Fri Oct  4 2013 coolo@suse.com
- updated to 2.19
  - Change VERSION => $VERSION in Makefile.PL to VERSION_FROM => 'lib/Config/Tiny.pm'.
    Reported by Jean-Louis Morel. See RT#88670.
  2.18  Sat Sep 14 10:03:00 2013
  - Remove obsolete and wrong version # from Makefile.PL.
    Reported by Jean-Louis Morel. See RT#88658.
  - Implement Kevin Ryde's suggestion to test if read() will return undef.
    If so, set an error message and (still) return undef.
  2.17  Fri Sep 13 12:41:00 2013
  - Remove the file tests -efr during calls to read(). The open() tests for any error.
    Also, the -f test was reporting /dev/null as a directory, not a file.
    Thanx to Kevin Ryde for pushing me to implement this. See RT#36974.
  - Clean up some error messages slightly.
  2.16  Fri Sep  6 11:54:00 2013
  - Replace Path::Tiny with File::Spec, because the former's list of dependencies is soooo long :-(.
    Changed files: t/02.main.t, t/04.utf8.t, Build.PL and Makefile.PL.
    See: RT#88435 (for Tree::DAG_Node) for an explanation.
  2.15  Sun Aug  4 14:59:00 2013
  - Clean up the shambolic dates in this file.
  - Add a note under Caveats about setting options more that once. Only the first case is respected.
    Thanx to Kimmel K. See RT#69795.
  - Add a $encoding parameter to read_file() and write_file(). See docs for details.
    Add t/04.utf8.t and t/04.utf8.txt.
    Thanx to Mark Lawrence and Wolfgang Husmann. See RT#71029 and RT#85571.
  - For BSD-based systems, when writing a file during tests, use:
    my($temp_dir) = File::Temp -> newdir('temp.XXXX', CLEANUP => 1, EXLOCK => 0, TMPDIR => 1);
  - Rename t/*.t files. I use '.' rather than '_' in file names because the latter is a shift char.
  - Add MANIFEST.SKIP, Changelog.ini, Build.PL, META.json.
  - Add an FAQ to the docs.
  - Clean up the docs.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Thu Mar 24 2011 pascal.bleser@opensuse.org
- update to 2.14:
  * fix RT#63080: module can write multiline values but not read them
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- update to 2.13
  - Resolved #60703: Display glitch in Config::Tiny 2.12 POD
  - Resolved #40585: member 'set;' doesn't exist
  - Resolved #30479: does not warn or die when writing data it
- created by cpanspec 1.78
- noarch pkg
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sat Jan 19 2008 gerrit.beine@googlemail.com
- moved to openSUSE Build Service
* Thu Dec  6 2007 gerrit@beine-computer.de
- first release 2.12
